==> sal-cluster-admin-api-1.9.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/md/sal/cluster/admin/rev151013/GetPrefixShardRoleOutputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link GetPrefixShardRoleOutputBuilder} instances.
 *
 * @see GetPrefixShardRoleOutputBuilder
 *
 */
public class GetPrefixShardRoleOutputBuilder implements Builder<GetPrefixShardRoleOutput> {

    private String _role;


    Map<Class<? extends Augmentation<GetPrefixShardRoleOutput>>, Augmentation<GetPrefixShardRoleOutput>> augmentation = Collections.emptyMap();

    public GetPrefixShardRoleOutputBuilder() {
    }

    public GetPrefixShardRoleOutputBuilder(GetPrefixShardRoleOutput base) {
        this._role = base.getRole();
        if (base instanceof GetPrefixShardRoleOutputImpl) {
            GetPrefixShardRoleOutputImpl impl = (GetPrefixShardRoleOutputImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<GetPrefixShardRoleOutput>>, Augmentation<GetPrefixShardRoleOutput>> aug =((AugmentationHolder<GetPrefixShardRoleOutput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }


    public String getRole() {
        return _role;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<GetPrefixShardRoleOutput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public GetPrefixShardRoleOutputBuilder setRole(final String value) {
        this._role = value;
        return this;
    }
    
    public GetPrefixShardRoleOutputBuilder addAugmentation(Class<? extends Augmentation<GetPrefixShardRoleOutput>> augmentationType, Augmentation<GetPrefixShardRoleOutput> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public GetPrefixShardRoleOutputBuilder removeAugmentation(Class<? extends Augmentation<GetPrefixShardRoleOutput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public GetPrefixShardRoleOutput build() {
        return new GetPrefixShardRoleOutputImpl(this);
    }

    private static final class GetPrefixShardRoleOutputImpl implements GetPrefixShardRoleOutput {
    
        private final String _role;
    
        private Map<Class<? extends Augmentation<GetPrefixShardRoleOutput>>, Augmentation<GetPrefixShardRoleOutput>> augmentation = Collections.emptyMap();
    
        GetPrefixShardRoleOutputImpl(GetPrefixShardRoleOutputBuilder base) {
            this._role = base.getRole();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<GetPrefixShardRoleOutput> getImplementedInterface() {
            return GetPrefixShardRoleOutput.class;
        }
    
        @Override
        public String getRole() {
            return _role;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<GetPrefixShardRoleOutput>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_role);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!GetPrefixShardRoleOutput.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            GetPrefixShardRoleOutput other = (GetPrefixShardRoleOutput)obj;
            if (!Objects.equals(_role, other.getRole())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                GetPrefixShardRoleOutputImpl otherImpl = (GetPrefixShardRoleOutputImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<GetPrefixShardRoleOutput>>, Augmentation<GetPrefixShardRoleOutput>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("GetPrefixShardRoleOutput");
            CodeHelpers.appendValue(helper, "_role", _role);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> sal-cluster-admin-api-1.10.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/md/sal/cluster/admin/rev151013/GetPrefixShardRoleOutputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link GetPrefixShardRoleOutputBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     GetPrefixShardRoleOutputBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new GetPrefixShardRoleOutputBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of GetPrefixShardRoleOutputBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see GetPrefixShardRoleOutputBuilder
 * @see Builder
 *
 */
public class GetPrefixShardRoleOutputBuilder implements Builder<GetPrefixShardRoleOutput> {

    private String _role;


    Map<Class<? extends Augmentation<GetPrefixShardRoleOutput>>, Augmentation<GetPrefixShardRoleOutput>> augmentation = Collections.emptyMap();

    public GetPrefixShardRoleOutputBuilder() {
    }

    public GetPrefixShardRoleOutputBuilder(GetPrefixShardRoleOutput base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<GetPrefixShardRoleOutput>>, Augmentation<GetPrefixShardRoleOutput>> aug =((AugmentationHolder<GetPrefixShardRoleOutput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._role = base.getRole();
    }


    public String getRole() {
        return _role;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<GetPrefixShardRoleOutput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public GetPrefixShardRoleOutputBuilder setRole(final String value) {
        this._role = value;
        return this;
    }
    
    public GetPrefixShardRoleOutputBuilder addAugmentation(Class<? extends Augmentation<GetPrefixShardRoleOutput>> augmentationType, Augmentation<GetPrefixShardRoleOutput> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public GetPrefixShardRoleOutputBuilder removeAugmentation(Class<? extends Augmentation<GetPrefixShardRoleOutput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public GetPrefixShardRoleOutput build() {
        return new GetPrefixShardRoleOutputImpl(this);
    }

    private static final class GetPrefixShardRoleOutputImpl
        extends AbstractAugmentable<GetPrefixShardRoleOutput>
        implements GetPrefixShardRoleOutput {
    
        private final String _role;
    
        GetPrefixShardRoleOutputImpl(GetPrefixShardRoleOutputBuilder base) {
            super(base.augmentation);
            this._role = base.getRole();
        }
    
        @Override
        public String getRole() {
            return _role;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_role);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!GetPrefixShardRoleOutput.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            GetPrefixShardRoleOutput other = (GetPrefixShardRoleOutput)obj;
            if (!Objects.equals(_role, other.getRole())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                GetPrefixShardRoleOutputImpl otherImpl = (GetPrefixShardRoleOutputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<GetPrefixShardRoleOutput>>, Augmentation<GetPrefixShardRoleOutput>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("GetPrefixShardRoleOutput");
            CodeHelpers.appendValue(helper, "_role", _role);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
